# -*- encoding: utf-8 -*-
# -----------------------------------------------------------------------------
# @File Name  : app.py
# @Time       : 2020/11/18 下午12:45
# @Author     : X. Peng
# @Email      : acepengxiong@163.com
# @Software   : PyCharm
# -----------------------------------------------------------------------------


import logging
import redis
import os
import sys
import yaml
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker, scoped_session

env = sys.argv[-1]
work_dir = os.getcwd()
CFG_FILEPATH = work_dir + '/app/config/config.yaml'

config = yaml.load(open(CFG_FILEPATH, 'r'), Loader=yaml.FullLoader)


class TAMP_SQL(object):
    """[sqlalchemy 封装]

    Args:
        object ([type]): [description]

    Returns:
        [type]: [description]
    """

    def __init__(self, db_engine):
        # db = "mysql+mysqlconnector://root:password@localhost:3306/test"
        # engine = create_engine(db)
        # 创建DBSession类型:
        self.DBSession = scoped_session(sessionmaker(bind=db_engine))

    def __enter__(self):
        self.session = self.DBSession()
        return self.session

    def __exit__(self, ext_type, exc_val, exc_tb):
        print(ext_type)
        self.session.commit()
        self.session.close()

    def add(self, model):
        # model = User(id='5', name='Bob')
        # 添加到session:
        self.session.add(model)
        # 提交即保存到数据库:
        self.session.commit()

tamp_user_engine = create_engine(
    'mysql+pymysql://{user}:{password}@{host}:{port}/{db}?charset={charset}'.format(
        db=config[env]['MySQL']['tamp_user_db'],
        host=config[env]['MySQL']['host'],
        port=config[env]['MySQL']['port'],
        user=config[env]['MySQL']['user'],
        password=config[env]['MySQL']['password'],
        charset="utf8"
    ),
    echo=True
)
tamp_pay_engine = create_engine(
    'mysql+pymysql://{user}:{password}@{host}:{port}/{db}?charset={charset}'.format(
        db=config[env]['MySQL']['tamp_pay_db'],
        host=config[env]['MySQL']['host'],
        port=config[env]['MySQL']['port'],
        user=config[env]['MySQL']['user'],
        password=config[env]['MySQL']['password'],
        charset="utf8"),
    echo=True
)
tamp_user_session = scoped_session(sessionmaker(bind=tamp_user_engine))()
tamp_pay_session = scoped_session(sessionmaker(bind=tamp_pay_engine))()

# redis = redis.StrictRedis(
#     host=config[env]['redis']['host'],
#     port=config[env]['redis']['port'],
#     db=config[env]['redis']['db']
# )

logging.basicConfig(level=logging.INFO,
                    filename=work_dir + config[env]['log']['filename'],
                    filemode=config[env]['log']['filemode'],
                    format=config[env]['log']['format'],
                    datefmt=config[env]['log']['datefmt']
                    )

